@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-bray
-;; Package-Version: 20260104.1048
-;; Package-Revision: ff193c20d8dc
+;; Package-Version: 20260108.326
+;; Package-Revision: ad06429ac60a
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -140,7 +140,7 @@ to perform any special logic that depends on the previous state.")
 
 
 ;; ---------------------------------------------------------------------------
-;; Forward Declorations
+;; Forward Declarations
 
 (declare-function bray-state-map--auxiliary-maps "bray-state-map")
 (declare-function bray-state-map-set "bray-state-map")
@@ -193,10 +193,10 @@ to perform any special logic that depends on the previous state.")
   "Return the :is-input from state S."
   (aref s 5))
 (defsubst bray--state-var-state-hook-enter-symbol (s)
-  "Return the :hook-enter from state S."
+  "Return the :enter-hook from state S."
   (aref s 6))
 (defsubst bray--state-var-state-hook-exit-symbol (s)
-  "Return the :hook-exit from state S."
+  "Return the :exit-hook from state S."
   (aref s 7))
 
 
